@@ -12,13 +12,20 @@ from crawlMp.results import Results
 class CrawlMp:
     """
     Crawl Manager, spawns workers that crawl through links.
+    If keepalive is True, crawlMp keep Workers running and waiting for new links to crawl.
+    One batch is finished, after all links were crawled.
+    This is useful to manage multiple searches while in keepalive loop.
     """
+    stopped = False
+    batch_id = 0
 
-    def __init__(self, crawler_class: Type[Crawler], links: list, num_proc: int = 4, buffer_size: int = 96, *args: Any,
-                 **kwargs: Any) -> None:
+    def __init__(self, crawler_class: Type[Crawler], links: list, keepalive=True, on_batch_done: Callable = None,
+                 num_proc: int = 4, buffer_size: int = 96, *args: Any, **kwargs: Any) -> None:
         """
         :param crawler_class: Crawler class to use with Worker
         :param list links: List of entrypoints
+        :param bool keepalive: don't stop workers after crawl finishes
+        :param callable on_batch_done: callback on finished batch
         :param int num_proc: Number of processes
         :param int buffer_size: Size of links buffer
         :param args:
@@ -29,6 +36,8 @@ class CrawlMp:
         self.num_proc = num_proc
         self.crawler_class = crawler_class
         self.jobs_list = share_manager.list(links)
+        self.keepalive = keepalive
+        self.on_batch_done = on_batch_done
         self.jobs_acquiring_lock = Lock()
         self.args = args
         self.kwargs = kwargs
@@ -38,6 +47,7 @@ class CrawlMp:
         self.sig_resumed = Event()
         self.sig_paused = Event()
         self.sig_worker_idle = Event()
+        self.sig_batch_done = Event()
         self.lock_jobs_acq = Lock()
         self.results = Results(shared=True)
 
@@ -71,11 +81,12 @@ class CrawlMp:
         :return: None
         """
         self.running = False
+        self.stopped = True
         if self.is_paused():
             self.sig_paused.clear()
             self.sig_resumed.set()
 
-    def _start_mp(self, callback: Callable = None) -> Results:
+    def _start(self, callback: Callable = None) -> 'CrawlMp':
         """
         Start crawling using multiple workers.
         :param Callable callback: callback function
@@ -84,33 +95,37 @@ class CrawlMp:
         # Spawn and start all workers
         self._init_workers()
         while True:
-            jobs_count = len(self.jobs_list)
             idle_workers = 0
-            try:
-                self.sig_worker_idle.wait(timeout=1)
-                # If one of the Workers is Idle
-                # Count number of Idle workers
-                if jobs_count > 0:
-                    for worker in self.workers:
-                        if not worker.wake_signal.is_set():
-                            # Worker's wake_signal is low
-                            # Wake up Worker
-                            worker.wake_signal.set()
-                            idle_workers += 1
-                    # Clear worker idle signal
-                    self.sig_worker_idle.clear()
-                else:
-                    for worker in self.workers:
-                        if not worker.wake_signal.is_set():
-                            idle_workers += 1
-            except RuntimeError:
-                pass
-            finally:
-                if self.is_paused():
-                    self.sig_resumed.wait()
-                elif not self.running or (idle_workers == self.num_proc and jobs_count == 0):
-                    # All workers are idle and job_list is empty
-                    # All jobs are finished, close all workers
+            if not self.sig_worker_idle.wait(timeout=0.1) and self.stopped or not self.running:
+                # All workers are idle and job_list is empty
+                # All jobs are finished, close all workers
+                self.running = False
+                self.stop_workers()
+                break
+            # If one of the Workers is Idle
+            # Count number of Idle workers
+            if len(self.jobs_list) > 0:
+                for worker in self.workers:
+                    if not worker.wake_signal.is_set():
+                        # Worker's wake_signal is low
+                        # Wake up Worker
+                        worker.wake_signal.set()
+                # Clear worker idle signal
+                self.sig_worker_idle.clear()
+                continue
+
+            for worker in self.workers:
+                if not worker.wake_signal.is_set():
+                    idle_workers += 1
+            if self.is_paused():
+                self.sig_resumed.wait()
+            elif not self.sig_batch_done.is_set() and idle_workers == self.num_proc and len(self.jobs_list) == 0:
+                # All jobs in the batch are finished
+                self.sig_batch_done.set()
+                self.batch_id += 1
+                if self.on_batch_done is not None:
+                    self.on_batch_done(self)
+                if self.keepalive:
                     self.running = False
                     self.stop_workers()
                     break
@@ -120,65 +135,18 @@ class CrawlMp:
             worker.join()
         # Call the Callback if it's set
         if callback is not None:
-            callback(self.results)
+            callback(self)
         else:
-            return self.results
+            return self
 
-    def _start_sp(self, callback: Callable = None) -> Results:
-        """
-        Start crawling in single process.
-        Useful for small link sets when spawning processes would lead to overhead.
-        :param Callable callback: callback function
-        :return Results: results
-        """
+    def _init_start(self):
+        self.running = True
+        self.stopped = False
+        self.sig_resumed.clear()
+        self.sig_paused.clear()
+        self.sig_worker_idle.clear()
 
-        def flush_results(crawler) -> None:
-            """
-            Flush crawler results into shared worker results.
-            :return: None
-            """
-            self.results.hits += crawler.results.hits
-            self.results.links_followed += crawler.results.links_followed
-            self.results.links_skipped += crawler.results.links_skipped
-            crawler.results.reset()
-
-        iterations = 0
-        crawl = None
-        for crawl in self.crawler_class(self.jobs_list, *self.args, **self.kwargs):
-            if not self.running:
-                break
-            elif self.sig_paused.is_set():
-                self.sig_resumed.wait()
-            iterations += 1
-            if iterations % self.buffer_size == 0:
-                flush_results(crawl)
-
-        self.running = False
-        if crawl is not None:
-            self.results.hits_header = crawl.results.hits_header
-            # Flush rest of the results
-            flush_results(crawl)
-
-        # Call the Callback if it's set
-        if callback is not None:
-            callback(self.results)
-        else:
-            return self.results
-
-    def append_links(self, links: list) -> None:
-        """
-        Add links, thread safe.
-        :param list links: New links to crawl
-        :return: None
-        """
-        if not self.running:
-            raise CrawlException("Crawler is already finished.")
-        self.jobs_list += links
-        for worker in self.workers:
-            # Wake up all workers again
-            worker.wake_signal.set()
-
-    def start(self, callback: Callable = None, reset_results: bool = True) -> Results:
+    def start(self, callback: Callable = None, reset_results: bool = True):
         """
         Start crawl managers.
         If callback is set, then start crawlers in the Thread and call callback in the end.
@@ -186,17 +154,18 @@ class CrawlMp:
         :param callable callback: Callable
         :return: CrawlWorker or None
         """
-        self.running = True
+        if self.running:
+            raise CrawlException("Crawling is already running.")
 
+        self._init_start()
         if reset_results:
             self.results.reset()
-        start_method = self._start_mp if self.num_proc > 1 else self._start_sp
 
         if callback is None:
-            return start_method()
+            self._start()
         else:
             assert callable(callback)
-            Thread(target=start_method, args=(callback,)).start()
+            Thread(target=self._start, args=(callback,)).start()
 
             for worker in self.workers:
                 # Block until all workers are idle
@@ -232,3 +201,17 @@ class CrawlMp:
         :return bool: pause status
         """
         return self.sig_paused.is_set()
+
+    def append_links(self, links: list) -> None:
+        """
+        Add links, thread safe.
+        :param list links: New links to crawl
+        :return: None
+        """
+        if not self.running:
+            raise CrawlException("Crawler is already finished.")
+        self.jobs_list += links
+        for worker in self.workers:
+            # Wake up all workers again
+            worker.wake_signal.set()
+        self.sig_batch_done.clear()
