@@ -16,9 +16,9 @@ def done_cb(_, done_event):
 def test_crawlMp_num_proc(fake_fs, num_proc):
     done_event = Event()
     manager = CrawlMp(FileCrawler, links=["/"], num_proc=num_proc)
-    manager.start(callback=lambda results: done_cb(results, done_event))
+    manager.start(callback=lambda m: done_cb(m, done_event))
 
-    done_event.wait()
+    done_event.wait(timeout=60)
     assert done_event.is_set()
 
     assert len(manager.results.hits) == 1811
@@ -63,20 +63,6 @@ def test_crawlMp_buffer_size_fail(fake_fs, buff_size):
         CrawlMp(FileCrawler, links=["/"], buffer_size=buff_size)
 
 
-@pytest.mark.parametrize('factor', range(2, 10, 2))
-@pytest.mark.parametrize("num_proc", [1, 2])
-def test_crawlMp_append_link(fake_fs, factor, num_proc):
-    done_event = Event()
-    manager = CrawlMp(FileCrawler, links=["/"] * factor, num_proc=num_proc)
-    manager.start(callback=lambda results: done_cb(results, done_event))
-    manager.append_links(["/"] * factor)
-    done_event.wait(timeout=60)
-    assert done_event.is_set()
-    assert len(manager.results.hits) == 1811 * (2 * factor)
-    assert len(manager.results.links_followed) == 148 * (2 * factor)
-    assert len(manager.results.links_skipped) == 2 * (2 * factor)
-
-
 @pytest.mark.parametrize("num_proc", [1, 2])
 def test_crawlMp_append_fail(fake_fs, num_proc):
     done_event = Event()
@@ -87,6 +73,26 @@ def test_crawlMp_append_fail(fake_fs, num_proc):
         manager.append_links(["/"])
 
 
+def batch_done_cb(manager):
+    if manager.batch_id == 2:
+        manager.stop()
+
+@pytest.mark.parametrize("num_proc", [1, 2])
+def test_crawlMp_append_job_keep_alive(fake_fs, num_proc):
+    done_event = Event()
+    manager = CrawlMp(FileCrawler, links=["/"], num_proc=num_proc, keepalive=False, on_batch_done=batch_done_cb)
+    manager.start(callback=lambda results: done_cb(results, done_event))
+    sleep(2)
+    manager.append_links(["/"])
+
+    done_event.wait(timeout=60)
+    assert done_event.is_set()
+
+    assert len(manager.results.hits) == 3622
+    assert len(manager.results.links_followed) == 296
+    assert len(manager.results.links_skipped) == 4
+
+
 @pytest.mark.parametrize('factor', range(2, 10, 2))
 @pytest.mark.parametrize("pause_offset", [0.1, 0.5])
 @pytest.mark.parametrize("num_proc", [1, 2])
